@@ -1,3 +1,4 @@
+import logging
 import threading
 import tkinter as tk
 from tkinter import messagebox, ttk
@@ -9,6 +10,8 @@ from octopus_python_client.migration import Migration
 from octopus_python_client.release_deployment import ReleaseDeployment
 from octopus_python_client.utilities.helper import find_item, find_index
 
+logger = logging.getLogger(__name__)
+
 
 class SubmitWidgets(tk.Frame):
     NO_ITEMS_PER_ROW = 6
@@ -69,7 +72,7 @@ class SubmitWidgets(tk.Frame):
         space_item_frame.grid(sticky=tk.W)
 
     def set_new_item_name(self, event=None):
-        self.server.log_info_print(msg=str(event))
+        logger.info(msg=str(event))
         if self.has_item_name:
             item_name_id = self.item_id_name_var.get().split(SubmitWidgets.DIVIDER_BAR)
             item_name = item_name_id[0]
